#
# spec file for package clazy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clazy
Version:        1.6
Release:        lp152.4.3
Summary:        Qt oriented code checker based on the Clang framework
License:        LGPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://www.kdab.com/clazy-video/
Source0:        https://download.kde.org/stable/%{name}/%{version}/src/%{name}-%{version}.tar.xz
Patch0:         cmake-clang-cpp.patch
Patch1:         0001-Fix-build-issues-using-llvm-10.0.0.patch
Patch2:         0001-qstring-allocations-Fix-unit-tests-with-llvm-10.patch
BuildRequires:  clang
BuildRequires:  clang-devel >= 3.9
BuildRequires:  cmake >= 3.0
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(zlib)

%description
clazy is a compiler plugin which allows Clang to understand Qt semantics.
You get more than 50 Qt related compiler warnings, ranging from unneeded memory
allocations to misusage of API, including fix-its for automatic refactoring.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
export CXXFLAGS="`echo %{optflags} | sed 's#-fstack-clash-protection##'`"
export CFLAGS="$CXXFLAGS"

%cmake

%cmake_build

%install
%cmake_install

sed -i 's#%{_bindir}/env sh#/bin/sh#' %{buildroot}%{_bindir}/clazy

%files
%license COPYING-LGPL2.txt
%doc %{_datadir}/doc/clazy
%doc README.md HOWTO Changelog
%{_bindir}/clazy
%{_bindir}/clazy-standalone
%{_datadir}/metainfo/org.kde.clazy.metainfo.xml
%{_libdir}/ClazyPlugin.so
%{_mandir}/man1/clazy.1%{?ext_man}

%changelog
* Mon May  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-qstring-allocations-Fix-unit-tests-with-llvm-10.patch
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Fix-build-issues-using-llvm-10.0.0.patch
* Wed Nov 20 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
- Use %%autosetup to simplify maintenance
* Tue Oct 15 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.6:
  * New Checks:
  - heap-allocated-small-trivial-type
  - signal-with-return-value
  - qproperty-type-mismatch, contributed by Jean-Michaël Celerier
  * Removed level3. Moved all level3 checks to manual level.
  * Fixed regressions with LLVM 9.0
  * Minimum LLVM was bumped to 5.0
  * Fixit infrastructure was overhauled
  * Clazy no longer rewrites files directly, to avoid races
    when parallel invocations change the same header.
  * Clazy now exports a yaml file with the replacements, to be
    applied with clang-apply-replacements.
  * The way to enable code rewrite is now: -Xclang -plugin-arg-clazy
  - Xclang export-fixes for clang or -export-fixes=somefile.yaml for clazy-standalone
  * All other fixit arguments and fixit env variables were removed
- Update cmake-clang-cpp.patch to make clazy build with both clang 8 and 9.
* Sat Sep 28 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add cmake-clang-cpp.patch: fix build with LLVM 9.
- Replace outdated llvm-clang-devel dependency by clang-devel.
* Tue Jul 16 2019 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto.
- Remove workarounds for older openSUSE versions.
* Fri Feb  1 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.5
  * New Checks:
    ifndef-define-typo
    lowercase-qml-type-name
    qrequiredresult-candidates
  * New Fixits:
    range-loop now supports adding missing refs or const-ref
    range-loop now supports adding qAsConst()
    function-args-by-ref now adding missing refs or const-ref (experimental)
    Introduced CLAZY_FIXIT_SUFFIX env variable
  * Removed support for the obscure -DCLAZY_BUILD_UTILS_LIB to
    simplify the CMakeLists.txt
  * Renamed the clazy plugin from ClangLazy.so to ClazyPlugin.so
  * fully-qualified-moc-types now warns for slot/invokable return
    values too. They need to be fully qualified for QML.
  * Fixed a crash (clang assert) in raw-environment-function
- BuildRequire ncurses-devel instead of pkgconfig(ncurses) on Leap
  42.3 to fix build
* Tue Sep 25 2018 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.4
  * New Checks:
    connect-by-name
    skipped-base-class
    qstring-varargs
    fully-qualified-moc-types
    qt-keywords, with fixit included
    qhash-with-char-pointer-key
    wrong-qevent-cast
    static-pmf
    raw-environment-function
    empty-qstringliteral
  * auto-unexpected-qstringbuilder now also warns for lambdas
    returning QStringBuilder
  * performance optimizations
  * Added -header-filter=<regex> option to clazy-standalone. Only
    headers matching the regexp will have warnings, besides the
    .cpp file from the translation unit, which is never filtered
    out.
  * Added -ignore-dirs=<regex> option to clazy-standalone, and its
    CLAZY_IGNORE_DIRS env variable equivalent.
  * Added CLAZY_HEADER_FILTER env variable which adds above
    functionality to both clazy and clazy-standalone
  * unused-non-trivial-variable got
    unused-non-trivial-variable-no-whitelist option
  * unused-non-trivial-variable got user-blacklist and
    user-whitelist support
  * container-inside-loop is now a manual check instead of level2
  * HiddenLevel was renamed to ManualLevel
  * connect-3arg-lambda now warns when passing a lambda to
    QTimer::singleShot() or QMenu::addAction() without a context
    object
  * old-style-connect warns for QMenu::addAction() and
    QMessageBox::open() too now
* Tue Sep  4 2018 Martin Pluskal <mpluskal@suse.com>
- Small packaging adjustements
* Wed Aug 29 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add Clazy 1.3, a code checker based on the Clang framework.
